FDv2Streaming class final

Foreground streaming mode. Cache + polling initializers, then streaming with polling fallback. Suitable for mobile foreground and desktop use.

Inheritance

Constructors

FDv2Streaming()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited