LDLogLevel enum
Logging levels that can be used with LDLogger.
Set the log level to one of these values when constructing a LDLogger
to control level of log messages are enabled.
Going from lowest importance (and most verbose) to most importance, the
levels are: LDLogLevel.debug, LDLogLevel.info, LDLogLevel.warn,
and LDLogLevel.error.
You can also specify 'none' instead to disable all logging.
Values
- debug → const LDLogLevel
-
This level is for very detailed and verbose messages that are rarely useful except in diagnosing an unusual problem. This level is mostly used by SDK developers.
const LDLogLevel(0) - info → const LDLogLevel
-
This level is for informational messages that are logged during normal operation.
const LDLogLevel(1) - warn → const LDLogLevel
-
This level is for messages about unexpected conditions that may be worth noting, but that do not necessarily prevent things from working.
const LDLogLevel(2) - error → const LDLogLevel
-
This level is for errors that should not happen during normal operation and should be investigated.
const LDLogLevel(3) - none → const LDLogLevel
-
This level is not used for output; setting the minimum enabled level to LDLogLevel.none disables all output.
const LDLogLevel(4)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator <(
LDLogLevel other) → bool -
operator <=(
LDLogLevel other) → bool -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator >(
LDLogLevel other) → bool -
operator >=(
LDLogLevel other) → bool
Constants
-
values
→ const List<
LDLogLevel> - A constant List of the values in this enum, in order of their declaration.