TrackSeriesContext class final

Contextual information provided to track stages.

Constructors

TrackSeriesContext.internal({required String key, required LDContext context, LDValue? data, num? numericValue})

Properties

context LDContext
The context associated with the track operation.
final
data LDValue?
The data associated with the track operation.
final
hashCode int
The hash code for this object.
no setterinherited
key String
The key for the event being tracked.
final
numericValue num?
The metric value associated with the track operation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited